@@ -7,7 +7,7 @@ from ..ndmapping import  NdMapping, item_check
 from ..sheetcoords import Slice
 from .. import util
 from .grid import GridInterface
-from .interface import Interface
+from .interface import Interface, DataError
 
 
 class ImageInterface(GridInterface):
@@ -34,8 +34,8 @@ class ImageInterface(GridInterface):
             data = dict(zip(dimensions, data))
         if isinstance(data, dict):
             xs, ys = np.asarray(data[kdims[0].name]), np.asarray(data[kdims[1].name])
-            l, r, xdensity, invertx = util.bound_range(xs, None)
-            b, t, ydensity, inverty = util.bound_range(ys, None)
+            l, r, xdensity, invertx = util.bound_range(xs, None, eltype._time_unit)
+            b, t, ydensity, inverty = util.bound_range(ys, None, eltype._time_unit)
             kwargs['bounds'] = BoundingBox(points=((l, b), (r, t)))
             if len(vdims) == 1:
                 data = np.flipud(np.asarray(data[vdims[0].name]))
@@ -45,6 +45,14 @@ class ImageInterface(GridInterface):
                 data = data[:, ::-1]
             if inverty:
                 data = data[::-1, :]
+            expected = (len(ys), len(xs))
+            shape = data.shape[:2]
+            error = DataError if len(shape) > 1 else ValueError
+            if shape != expected and not (not expected and shape == (1,)):
+                raise error('Key dimension values and value array %s '
+                            'shapes do not match. Expected shape %s, '
+                            'actual shape: %s' % (vdims[0], expected, shape), cls)
+
         if not isinstance(data, np.ndarray) or data.ndim not in [2, 3]:
             raise ValueError('ImageInterface expects a 2D array.')
 
@@ -54,18 +62,18 @@ class ImageInterface(GridInterface):
     @classmethod
     def shape(cls, dataset, gridded=False):
         if gridded:
-            return dataset.data.shape
+            return dataset.data.shape[:2]
         else:
             return cls.length(dataset), len(dataset.dimensions())
 
 
     @classmethod
     def length(cls, dataset):
-        return np.product(dataset.data.shape)
+        return np.product(dataset.data.shape[:2])
 
 
     @classmethod
-    def validate(cls, dataset):
+    def validate(cls, dataset, vdims=True):
         pass
 
     @classmethod
@@ -102,11 +110,15 @@ class ImageInterface(GridInterface):
         if dim_idx in [0, 1] and obj.bounds:
             l, b, r, t = obj.bounds.lbrt()
             if dim_idx:
-                halfd = (1./obj.ydensity)/2.
-                drange = (b+halfd, t-halfd)
+                (low, high) = (b, t)
+                density = obj.ydensity
             else:
-                halfd = (1./obj.xdensity)/2.
-                drange = (l+halfd, r-halfd)
+                low, high = (l, r)
+                density = obj.xdensity
+            halfd = (1./density)/2.
+            if isinstance(low, util.datetime_types):
+                halfd = np.timedelta64(int(round(halfd)), obj._time_unit)
+            drange = (low+halfd, high-halfd)
         elif 1 < dim_idx < len(obj.vdims) + 2:
             dim_idx -= 2
             data = np.atleast_3d(obj.data)[:, :, dim_idx]
@@ -125,15 +137,21 @@ class ImageInterface(GridInterface):
         if dim_idx in [0, 1]:
             l, b, r, t = dataset.bounds.lbrt()
             dim2, dim1 = dataset.data.shape[:2]
-            d1_half_unit = float(r - l)/dim1/2.
-            d2_half_unit = float(t - b)/dim2/2.
-            d1lin = np.linspace(l+d1_half_unit, r-d1_half_unit, dim1)
-            d2lin = np.linspace(b+d2_half_unit, t-d2_half_unit, dim2)
+            if isinstance(l, util.datetime_types):
+                xlin = util.date_range(l, r, dim1, dataset._time_unit)
+            else:
+                xstep = float(r - l)/dim1
+                xlin = np.linspace(l+(xstep/2.), r-(xstep/2.), dim1)
+            if isinstance(b, util.datetime_types):
+                ylin = util.date_range(b, t, dim2, dataset._time_unit)
+            else:
+                ystep = float(t - b)/dim2
+                ylin = np.linspace(b+(ystep/2.), t-(ystep/2.), dim2)
             if expanded:
-                values = np.meshgrid(d2lin, d1lin)[abs(dim_idx-1)]
+                values = np.meshgrid(ylin, xlin)[abs(dim_idx-1)]
                 return values.flatten() if flat else values
             else:
-                return d2lin if dim_idx else d1lin
+                return ylin if dim_idx else xlin
         elif dataset.ndims <= dim_idx < len(dataset.dimensions()):
             # Raster arrays are stored with different orientation
             # than expanded column format, reorient before expanding
