@@ -11,7 +11,7 @@ import param
 
 from . import traversal, util
 from .dimension import OrderedDict, Dimension, ViewableElement, redim
-from .layout import Layout, AdjointLayout, NdLayout
+from .layout import Layout, AdjointLayout, NdLayout, Empty
 from .ndmapping import UniformNdMapping, NdMapping, item_check
 from .overlay import Overlay, CompositeOverlay, NdOverlay, Overlayable
 from .options import Store, StoreOptions
@@ -225,7 +225,7 @@ class HoloMap(UniformNdMapping, Overlayable):
 
 
     def __lshift__(self, other):
-        if isinstance(other, (ViewableElement, UniformNdMapping)):
+        if isinstance(other, (ViewableElement, UniformNdMapping, Empty)):
             return AdjointLayout([self, other])
         elif isinstance(other, AdjointLayout):
             return AdjointLayout(other.data+[self])
@@ -570,10 +570,11 @@ def get_nested_dmaps(dmap):
     """
     Get all DynamicMaps referenced by the supplied DynamicMap's callback.
     """
+    if not isinstance(dmap, DynamicMap):
+        return []
     dmaps = [dmap]
     for o in dmap.callback.inputs:
-        if isinstance(o, DynamicMap):
-            dmaps.extend(get_nested_dmaps(o))
+        dmaps.extend(get_nested_dmaps(o))
     return list(set(dmaps))
 
 
