@@ -180,7 +180,7 @@ class periodic(Thread):
             self.counter += 1
             try:
                 self.callback(self.counter)
-            except Exception as e:
+            except Exception:
                 self.stop()
 
             if self.timeout is not None:
@@ -213,7 +213,7 @@ else:
     basestring = basestring
     unicode = unicode
     from itertools import izip
-    generator_types = (izip, xrange, types.GeneratorType)
+    generator_types = (izip, xrange, types.GeneratorType) # noqa
 
 
 
@@ -1555,8 +1555,14 @@ def dt_to_int(value, time_unit='us'):
     """
     Converts a datetime type to an integer with the supplied time unit.
     """
-    if time_unit == 'ns':
-        tscale = 1./np.timedelta64(1, time_unit).tolist()
+    if isinstance(value, np.datetime64):
+        value = np.datetime64(value, 'ns')
+        if time_unit == 'ns':
+            tscale = 1
+        else:
+            tscale = (np.timedelta64(1, time_unit)/np.timedelta64(1, 'ns')) * 1000.
+    elif time_unit == 'ns':
+        tscale = 1000.
     else:
         tscale = 1./np.timedelta64(1, time_unit).tolist().total_seconds()
     if pd and isinstance(value, pd.Timestamp):
