@@ -17,6 +17,7 @@ methods on all objects as comparison operators only return Booleans and
 thus would not supply any information regarding *why* two elements are
 considered different.
 """
+from functools import partial
 import numpy as np
 from unittest.util import safe_repr
 from unittest import TestCase
@@ -27,10 +28,7 @@ from ..core import (Element, Empty, AdjointLayout, Overlay, Dimension,
                     HoloMap, Dimensioned, Layout, NdLayout, NdOverlay,
                     GridSpace, DynamicMap, GridMatrix, OrderedDict)
 from ..core.options import Options, Cycle
-from ..interface.pandas import DFrame as PandasDFrame
-from ..interface.pandas import DataFrameView
-from ..interface.seaborn import DFrame, Bivariate, Distribution, \
-                                Regression, TimeSeries
+from ..core.util import pd
 
 
 class ComparisonInterface(object):
@@ -95,6 +93,9 @@ class Comparison(ComparisonInterface):
     Comparison.assertEqual(matrix1, matrix2)
     """
 
+    # someone might prefer to use a different function, e.g. assert_all_close
+    assert_array_almost_equal_fn = partial(assert_array_almost_equal, decimal=6)
+
     @classmethod
     def register(cls):
 
@@ -116,6 +117,10 @@ class Comparison(ComparisonInterface):
         # Numpy array comparison
         cls.equality_type_funcs[np.ndarray] =   cls.compare_arrays
 
+        # Pandas dataframe comparison
+        if pd:
+            cls.equality_type_funcs[pd.DataFrame] = cls.compare_dataframe
+
         # Dimension objects
         cls.equality_type_funcs[Dimension] =    cls.compare_dimensions
         cls.equality_type_funcs[Dimensioned] =  cls.compare_dimensioned  # Used in unit tests
@@ -159,6 +164,7 @@ class Comparison(ComparisonInterface):
         cls.equality_type_funcs[Area] =         cls.compare_area
         cls.equality_type_funcs[Scatter] =      cls.compare_scatter
         cls.equality_type_funcs[Scatter3D] =    cls.compare_scatter3d
+        cls.equality_type_funcs[TriSurface] =   cls.compare_trisurface
         cls.equality_type_funcs[Trisurface] =   cls.compare_trisurface
         cls.equality_type_funcs[Histogram] =    cls.compare_histogram
         cls.equality_type_funcs[Bars] =         cls.compare_bars
@@ -166,21 +172,19 @@ class Comparison(ComparisonInterface):
         cls.equality_type_funcs[BoxWhisker] =   cls.compare_boxwhisker
         cls.equality_type_funcs[VectorField] =  cls.compare_vectorfield
 
+        # Graphs
+        cls.equality_type_funcs[Graph] =        cls.compare_graph
+        cls.equality_type_funcs[Nodes] =        cls.compare_nodes
+        cls.equality_type_funcs[EdgePaths] =    cls.compare_edgepaths
+
         # Tables
         cls.equality_type_funcs[ItemTable] =    cls.compare_itemtables
         cls.equality_type_funcs[Table] =        cls.compare_tables
         cls.equality_type_funcs[Points] =       cls.compare_points
 
-        # Pandas DFrame objects
-        cls.equality_type_funcs[DataFrameView] = cls.compare_dframe
-        cls.equality_type_funcs[PandasDFrame] =  cls.compare_dframe
-        cls.equality_type_funcs[DFrame] =        cls.compare_dframe
-
         # Seaborn Views
         cls.equality_type_funcs[Bivariate] =    cls.compare_bivariate
         cls.equality_type_funcs[Distribution] = cls.compare_distribution
-        cls.equality_type_funcs[Regression] =   cls.compare_regression
-        cls.equality_type_funcs[TimeSeries] =   cls.compare_timeseries
 
         # NdMappings
         cls.equality_type_funcs[NdLayout] =      cls.compare_gridlayout
@@ -247,10 +251,15 @@ class Comparison(ComparisonInterface):
             assert_array_equal(arr1, arr2)
         except:
             try:
-                assert_array_almost_equal(arr1, arr2)
+                cls.assert_array_almost_equal_fn(arr1, arr2)
             except AssertionError as e:
                 raise cls.failureException(msg + str(e)[11:])
 
+    @classmethod
+    def compare_dataframe(cls, df1, df2, msg='DataFrames'):
+        if not df1.equals(df2):
+            raise cls.failureException('%s are not equal' % msg)
+
     @classmethod
     def bounds_check(cls, el1, el2, msg=None):
         if el1.bounds.lbrt() != el2.bounds.lbrt():
@@ -449,23 +458,21 @@ class Comparison(ComparisonInterface):
 
     @classmethod
     def compare_paths(cls, el1, el2, msg='Path'):
-        cls.compare_dimensioned(el1, el2)
+        cls.compare_dataset(el1, el2, msg)
 
-        if len(el1.data) != len(el2.data):
+        paths1 = el1.split()
+        paths2 = el2.split()
+        if len(paths1) != len(paths2):
             raise cls.failureException("%s objects do not have a matching number of paths." % msg)
-        for arr1, arr2 in zip(el1.data, el2.data):
-            cls.compare_arrays(arr1, arr2, '%s data' % msg)
+        for p1, p2 in zip(paths1, paths2):
+            cls.compare_dataset(p1, p2, '%s data' % msg)
 
     @classmethod
     def compare_contours(cls, el1, el2, msg='Contours'):
-        if el1.level != el2.level:
-            raise cls.failureException("Contour levels are mismatched")
         cls.compare_paths(el1, el2, msg=msg)
 
     @classmethod
     def compare_polygons(cls, el1, el2, msg='Polygons'):
-        if el1.level != el2.level:
-            raise cls.failureException("Polygon levels are mismatched")
         cls.compare_paths(el1, el2, msg=msg)
 
     @classmethod
@@ -529,7 +536,7 @@ class Comparison(ComparisonInterface):
         cls.compare_dataset(el1, el2, msg)
 
     @classmethod
-    def compare_trisurface(cls, el1, el2, msg='Trisurface'):
+    def compare_trisurface(cls, el1, el2, msg='TriSurface'):
         cls.compare_dataset(el1, el2, msg)
 
     @classmethod
@@ -559,6 +566,27 @@ class Comparison(ComparisonInterface):
     def compare_boxwhisker(cls, el1, el2, msg='BoxWhisker'):
         cls.compare_dataset(el1, el2, msg)
 
+
+    #=========#
+    # Graphs  #
+    #=========#
+
+    @classmethod
+    def compare_graph(cls, el1, el2, msg='Graph'):
+        cls.compare_dataset(el1, el2, msg)
+        cls.compare_nodes(el1.nodes, el2.nodes, msg)
+        if el1._edgepaths or el2._edgepaths:
+            cls.compare_edgepaths(el1.edgepaths, el2.edgepaths, msg)
+
+    @classmethod
+    def compare_nodes(cls, el1, el2, msg='Nodes'):
+        cls.compare_dataset(el1, el2, msg)
+
+    @classmethod
+    def compare_edgepaths(cls, el1, el2, msg='Nodes'):
+        cls.compare_paths(el1, el2, msg)
+
+
     #=========#
     # Rasters #
     #=========#
@@ -644,19 +672,10 @@ class Comparison(ComparisonInterface):
     def compare_distribution(cls, el1, el2, msg='Distribution'):
         cls.compare_dataset(el1, el2, msg)
 
-    @classmethod
-    def compare_timeseries(cls, el1, el2, msg='TimeSeries'):
-        cls.compare_dimensioned(el1, el2)
-        cls.compare_arrays(el1.data, el2.data, msg)
-
     @classmethod
     def compare_bivariate(cls, el1, el2, msg='Bivariate'):
         cls.compare_dataset(el1, el2, msg)
 
-    @classmethod
-    def compare_regression(cls, el1, el2, msg='Regression'):
-        cls.compare_dataset(el1, el2, msg)
-
     #=======#
     # Grids #
     #=======#
