@@ -201,11 +201,11 @@ class ElementPlot(GenericElementPlot, MPLPlot):
                 self._set_axis_limits(axis, element, subplots, ranges)
 
             # Apply aspects
-            if self.aspect is not None and self.projection != 'polar':
+            if self.aspect is not None and self.projection != 'polar' and not self.adjoined:
                 self._set_aspect(axis, self.aspect)
 
         if not subplots and not self.drawn:
-            self._finalize_artist(key)
+            self._finalize_artist(element)
 
         for hook in self.finalize_hooks:
             try:
@@ -342,22 +342,27 @@ class ElementPlot(GenericElementPlot, MPLPlot):
             if self.invert_xaxis or any(p.invert_xaxis for p in subplots):
                 r, l = l, r
             if l != r:
+                lims = {}
                 if valid_lim(l):
-                    axis.set_xlim(left=l)
+                    lims['left'] = l
                     scalex = False
                 if valid_lim(r):
-                    axis.set_xlim(right=r)
+                    lims['right'] = r
                     scalex = False
-
+                if lims:
+                    axis.set_xlim(**lims)
             if self.invert_yaxis or any(p.invert_yaxis for p in subplots):
                 t, b = b, t
             if b != t:
+                lims = {}
                 if valid_lim(b):
-                    axis.set_ylim(bottom=b)
+                    lims['bottom'] = b
                     scaley = False
                 if valid_lim(t):
-                    axis.set_ylim(top=t)
+                    lims['top'] = t
                     scaley = False
+                if lims:
+                    axis.set_ylim(**lims)
         axis.autoscale_view(scalex=scalex, scaley=scaley)
 
 
@@ -585,7 +590,7 @@ class ColorbarPlot(ElementPlot):
             cbar.set_ticklabels(labels)
 
 
-    def _finalize_artist(self, key):
+    def _finalize_artist(self, element):
         artist = self.handles.get('artist', None)
         if artist and self.colorbar:
             self._draw_colorbar()
@@ -640,12 +645,12 @@ class ColorbarPlot(ElementPlot):
         ColorbarPlot._colorbars[id(axis)] = (ax_colorbars, (l, b, w, h))
 
 
-    def _norm_kwargs(self, element, ranges, opts, vdim):
+    def _norm_kwargs(self, element, ranges, opts, vdim, prefix=''):
         """
         Returns valid color normalization kwargs
         to be passed to matplotlib plot function.
         """
-        clim = opts.pop('clims', None)
+        clim = opts.pop(prefix+'clims', None)
         if clim is None:
             cs = element.dimension_values(vdim)
             if not isinstance(cs, np.ndarray):
@@ -669,18 +674,21 @@ class ColorbarPlot(ElementPlot):
                                              linthresh=clim[1]/np.e)
             else:
                 norm = mpl_colors.LogNorm(vmin=clim[0], vmax=clim[1])
-            opts['norm'] = norm
-        opts['vmin'] = clim[0]
-        opts['vmax'] = clim[1]
+            opts[prefix+'norm'] = norm
+        opts[prefix+'vmin'] = clim[0]
+        opts[prefix+'vmax'] = clim[1]
 
         # Check whether the colorbar should indicate clipping
         values = np.asarray(element.dimension_values(vdim))
         if values.dtype.kind not in 'OSUM':
-            el_min, el_max = np.nanmin(values), np.nanmax(values)
+            try:
+                el_min, el_max = np.nanmin(values), np.nanmax(values)
+            except ValueError:
+                el_min, el_max = -np.inf, np.inf
         else:
             el_min, el_max = -np.inf, np.inf
-        vmin = -np.inf if opts['vmin'] is None else opts['vmin']
-        vmax = np.inf if opts['vmax'] is None else opts['vmax']
+        vmin = -np.inf if opts[prefix+'vmin'] is None else opts[prefix+'vmin']
+        vmax = np.inf if opts[prefix+'vmax'] is None else opts[prefix+'vmax']
         if el_min < vmin and el_max > vmax:
             self._cbar_extend = 'both'
         elif el_min < vmin:
@@ -689,7 +697,13 @@ class ColorbarPlot(ElementPlot):
             self._cbar_extend = 'max'
 
         # Define special out-of-range colors on colormap
-        cmap = copy.copy(plt.cm.get_cmap(opts.get('cmap')))
+        cmap = opts.get(prefix+'cmap')
+        if isinstance(cmap, list):
+            cmap = mpl_colors.ListedColormap(cmap)
+        elif isinstance(cmap, util.basestring):
+            cmap = copy.copy(plt.cm.get_cmap(cmap))
+        else:
+            cmap = copy.copy(cmap)
         colors = {}
         for k, val in self.clipping_colors.items():
             if isinstance(val, tuple):
@@ -705,7 +719,7 @@ class ColorbarPlot(ElementPlot):
         if 'max' in colors: cmap.set_over(**colors['max'])
         if 'min' in colors: cmap.set_under(**colors['min'])
         if 'NaN' in colors: cmap.set_bad(**colors['NaN'])
-        opts['cmap'] = cmap
+        opts[prefix+'cmap'] = cmap
 
 
 
@@ -757,7 +771,7 @@ class OverlayPlot(LegendPlot, GenericOverlayPlot):
     _propagate_options = ['aspect', 'fig_size', 'xaxis', 'yaxis', 'zaxis',
                           'labelled', 'bgcolor', 'fontsize', 'invert_axes',
                           'show_frame', 'show_grid', 'logx', 'logy', 'logz',
-                          'xticks', 'yticks', 'zticks', 'xrotation', 'yrotation'
+                          'xticks', 'yticks', 'zticks', 'xrotation', 'yrotation',
                           'zrotation', 'invert_xaxis', 'invert_yaxis',
                           'invert_zaxis', 'title_format']
 
@@ -767,9 +781,9 @@ class OverlayPlot(LegendPlot, GenericOverlayPlot):
         super(OverlayPlot, self).__init__(overlay, ranges=ranges, **params)
 
 
-    def _finalize_artist(self, key):
+    def _finalize_artist(self, element):
         for subplot in self.subplots.values():
-            subplot._finalize_artist(key)
+            subplot._finalize_artist(element)
 
     def _adjust_legend(self, overlay, axis):
         """
@@ -809,7 +823,7 @@ class OverlayPlot(LegendPlot, GenericOverlayPlot):
         else:
             leg_spec = self.legend_specs[self.legend_position]
             if self.legend_cols: leg_spec['ncol'] = self.legend_cols
-            leg = axis.legend(data.keys(), data.values(),
+            leg = axis.legend(list(data.keys()), list(data.values()),
                               title=title, scatterpoints=1,
                               **dict(leg_spec, **self._fontsize('legend')))
             title_fontsize = self._fontsize('legend_title')
@@ -838,7 +852,7 @@ class OverlayPlot(LegendPlot, GenericOverlayPlot):
                 frame = element.get(k, None)
                 subplot.current_frame = frame
 
-        if self.show_legend:
+        if self.show_legend and element is not None:
             self._adjust_legend(element, axis)
 
         return self._finalize_axis(key, element=element, ranges=ranges,
