@@ -1,12 +1,15 @@
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
+
 from collections import defaultdict
 import traceback
+import warnings
 
 import numpy as np
 import param
 
 from ..core import (HoloMap, DynamicMap, CompositeOverlay, Layout,
-                    Overlay, GridSpace, NdLayout, Store)
+                    Overlay, GridSpace, NdLayout, Store, NdOverlay)
+from ..core.options import Cycle
 from ..core.spaces import get_nested_streams
 from ..core.util import (match_spec, is_number, wrap_tuple, basestring,
                          get_overlay_spec, unique_iterator)
@@ -116,6 +119,13 @@ def compute_overlayable_zorders(obj, path=[]):
         if isinstance(obj, CompositeOverlay):
             for z, o in enumerate(obj):
                 zorder_map[z] = [o, obj]
+        elif isinstance(obj, HoloMap):
+            for el in obj.values():
+                if isinstance(el, CompositeOverlay):
+                    for k, v in compute_overlayable_zorders(el, path).items():
+                        zorder_map[k] += v + [obj]
+                else:
+                    zorder_map[0] += [obj, el]
         else:
             if obj not in zorder_map[0]:
                 zorder_map[0].append(obj)
@@ -166,6 +176,52 @@ def compute_overlayable_zorders(obj, path=[]):
     return zorder_map
 
 
+def is_dynamic_overlay(dmap):
+    """
+    Traverses a DynamicMap graph and determines if any components
+    were overlaid dynamically (i.e. by * on a DynamicMap).
+    """
+    if not isinstance(dmap, DynamicMap):
+        return False
+    elif dmap.callback._is_overlay:
+        return True
+    else:
+        return any(is_dynamic_overlay(dm) for dm in dmap.callback.inputs)
+
+
+def split_dmap_overlay(obj, depth=0):
+    """
+    Splits a DynamicMap into the original component layers it was
+    constructed from by traversing the graph to search for dynamically
+    overlaid components (i.e. constructed by using * on a DynamicMap).
+    Useful for assigning subplots of an OverlayPlot the streams that
+    are responsible for driving their updates. Allows the OverlayPlot
+    to determine if a stream update should redraw a particular
+    subplot.
+    """
+    layers = []
+    if isinstance(obj, DynamicMap):
+        if issubclass(obj.type, NdOverlay) and not depth:
+            for v in obj.last.values():
+                layers.append(obj)
+        elif issubclass(obj.type, Overlay):
+            if obj.callback.inputs and is_dynamic_overlay(obj):
+                for inp in obj.callback.inputs:
+                    layers += split_dmap_overlay(inp, depth+1)
+            else:
+                for v in obj.last.values():
+                    layers.append(obj)
+        else:
+            layers.append(obj)
+        return layers
+    if isinstance(obj, Overlay):
+        for k, v in obj.items():
+            layers.append(v)
+    else:
+        layers.append(obj)
+    return layers
+
+
 def initialize_dynamic(obj):
     """
     Initializes all DynamicMap objects contained by the object
@@ -411,6 +467,63 @@ def map_colors(arr, crange, cmap, hex=True):
         return arr
 
 
+def mplcmap_to_palette(cmap, ncolors=None):
+    """
+    Converts a matplotlib colormap to palette of RGB hex strings."
+    """
+    from matplotlib.colors import Colormap
+    if not isinstance(cmap, Colormap):
+        import matplotlib.cm as cm
+        cmap = cm.get_cmap(cmap) #choose any matplotlib colormap here
+    if ncolors:
+        return [rgb2hex(cmap(i)) for i in np.linspace(0, 1, ncolors)]
+    return [rgb2hex(m) for m in cmap(np.arange(cmap.N))]
+
+
+def bokeh_palette_to_palette(cmap, ncolors=None):
+    from bokeh import palettes
+    # Process as bokeh palette
+    palette = getattr(palettes, cmap, None)
+    if palette is None:
+        raise ValueError("Supplied palette %s not found among bokeh palettes" % cmap)
+    elif isinstance(palette, dict):
+         if ncolors in palette:
+             palette = palette[ncolors]
+         else:
+             palette = sorted(palette.items())[-1][1]
+    if ncolors:
+        return [palette[i%len(palette)] for i in range(ncolors)]
+    return list(palette)
+
+
+def process_cmap(cmap, ncolors=None):
+    """
+    Convert valid colormap specifications to a list of colors.
+    """
+    if isinstance(cmap, Cycle):
+        palette = [rgb2hex(c) if isinstance(c, tuple) else c for c in cmap.values]
+    elif isinstance(cmap, list):
+        palette = cmap
+    else:
+        try:
+            # Process as matplotlib colormap
+            palette = mplcmap_to_palette(cmap, ncolors)
+        except:
+            try:
+                palette = bokeh_palette_to_palette(cmap, ncolors)
+            except:
+                if isinstance(cmap, basestring):
+                    raise ValueError("Supplied cmap %s not found among "
+                                     "matplotlib or bokeh colormaps." % cmap)
+                palette = None
+    if not isinstance(palette, list):
+        raise TypeError("cmap argument expects a list, Cycle or valid matplotlib "
+                        "colormap or bokeh palette, found %s." % cmap)
+    if ncolors:
+        return [palette[i%len(palette)] for i in range(ncolors)]
+    return palette
+
+
 def dim_axis_label(dimensions, separator=', '):
     """
     Returns an axis label for one or more dimensions.
@@ -438,19 +551,32 @@ def traverse_setter(obj, attribute, value):
     obj.traverse(lambda x: setattr(x, attribute, value))
 
 
+def _get_min_distance_numpy(element):
+    """
+    NumPy based implementation of get_min_distance
+    """
+    xys = element.array([0, 1])
+    with warnings.catch_warnings():
+        warnings.filterwarnings('ignore', r'invalid value encountered in')
+        xys = xys.astype('float32').view(np.complex64)
+        distances = np.abs(xys.T-xys)
+        np.fill_diagonal(distances, np.inf)
+        distances = distances[distances>0]
+        if len(distances):
+            return distances.min()
+    return 0
+    
+
 def get_min_distance(element):
     """
     Gets the minimum sampling distance of the x- and y-coordinates
     in a grid.
     """
-    xys = element.array([0, 1]).astype('float64').view(dtype=np.complex128)
-    m, n = np.meshgrid(xys, xys)
-    distances = np.abs(m-n)
-    np.fill_diagonal(distances, np.inf)
-    distances = distances[distances>0]
-    if len(distances):
-        return distances.min()
-    return 0
+    try:
+        from scipy.spatial.distance import pdist
+        return pdist(element.array([0, 1])).min()
+    except:
+        return _get_min_distance_numpy(element)
 
 
 def rgb2hex(rgb):
